@@ -3,13 +3,13 @@ import sympy
 import IPython
 
 DatosList = []
-
+Documento = ""
 #https://widdowquinn.github.io/coding/update-pypi-package/
 
 #_print_Symbol
 
 def Inicializar(n):
-  global DatosList,Orden,Estilo
+  global DatosList,Orden,Estilo,Documento
 
   if  n ==1:
     Estilo = "textrm"#roman
@@ -22,7 +22,8 @@ def Inicializar(n):
 
   DatosList = [[sympy.pi,3.14]]
   Orden = 8
-  return DatosList,Orden
+  Documento = ""
+  return DatosList,Orden,Documento
 
 def search(symbolo):
   for c_element in DatosList:
@@ -68,6 +69,7 @@ def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar qu
     #texto = texto.replace("text", Estilo)
 
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
+    Documento = Documento + " /n"+str(texto)
 
   if Tipo == "Componente":#Si hemos identificado el elemento ingresado como un componente, entonces lo imprimimos en rojo
 
@@ -85,7 +87,7 @@ def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar qu
     texto = a + b + c
       #texto = texto.replace("text", Estilo)
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
-
+    Documento = Documento + " /n"+str(texto)
 
 #def E(expr,color = "red"):
 #  DataRealSymbolList = []#Guarda en formato symbolo todos los Datos
@@ -132,7 +134,7 @@ def S(c_componente):#Guardar
   
   if dentro == False:
     
-    DatosList.append(c_componente)#Si el emento no estaba adentro, simplemente lo agregamos.
+    DatosList.append(c_componente)#Si el elemento no estaba adentro, simplemente lo agregamos.
   
   #Renderizado Gris
   if c_componente[1] == None or dentro == False:
@@ -170,3 +172,4 @@ def E(expr,color ="black"):
     texto = sympy.latex(expr[0]) + " = " + latemix(expr[1])
     return IPython.display.display(IPython.display.Latex(texto))
 
+
